@@ -3,7 +3,7 @@ BEGIN {
   $Dancer::Plugin::FontSubset::AUTHORITY = 'cpan:YANICK';
 }
 {
-  $Dancer::Plugin::FontSubset::VERSION = '0.1.0';
+  $Dancer::Plugin::FontSubset::VERSION = '0.1.1';
 }
 # ABSTRACT: Generate font subsets on-the-fly
 
@@ -18,7 +18,7 @@ use Font::TTF::Scripts::Name;
 use Moo;
 with 'MooX::Singleton';
 
-has config => (
+has _config => (
     is => 'ro',
     lazy => 1,
     default => sub { 
@@ -30,7 +30,7 @@ has fonts_dir => (
     is => 'ro',
     lazy => 1,
     default => sub {
-        $_[0]->config->{fonts_dir} || 'public/fonts';
+        $_[0]->_config->{fonts_dir} || 'public/fonts';
     },
 );
 
@@ -38,7 +38,7 @@ has font_base_url => (
     is => 'ro',
     lazy => 1,
     default => sub {
-        $_[0]->config->{font_base_url} || '/font';
+        $_[0]->_config->{font_base_url} || '/font';
     },
 );
 
@@ -46,7 +46,7 @@ has use_cache => (
     is => 'ro',
     lazy => 1,
     default => sub {
-        $_[0]->config->{use_cache};
+        $_[0]->_config->{use_cache};
     },
 );
 
@@ -885,7 +885,7 @@ Dancer::Plugin::FontSubset - Generate font subsets on-the-fly
 
 =head1 VERSION
 
-version 0.1.0
+version 0.1.1
 
 =head1 SYNOPSIS
 
